@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.117';
+$Config::Model::VERSION = '2.133';
 use strict ;
 use warnings;
 use 5.10.1;
@@ -30,10 +30,10 @@ use Cwd;
 use Config::Model::Lister;
 
 use parent qw/Exporter/;
-our @EXPORT_OK = qw/cme/;
+our @EXPORT_OK = qw/cme initialize_log4perl/;
 
 # this class holds the version number of the package
-use vars qw(@status @level %default_property);
+use vars qw(@status @level %default_property $force_default_log);
 
 my $legacy_logger = get_logger("Model::Legacy") ;
 my $loader_logger = get_logger("Model::Loader") ;
@@ -182,55 +182,48 @@ around BUILDARGS => sub {
 # keep this as a separate sub from BUILD. So user can call it before
 # creating Config::Model object
 sub initialize_log4perl {
-    my $self = shift;
-    my $args = shift;
+    if (ref $_[0]) {
+        # may be called as $self-> initialize_log4perl
+        shift;
+    }
+
+    my %args = @_;
 
     my $log4perl_syst_conf_file = path('/etc/log4config-model.conf');
     # avoid undef warning when homedir is not defined (e.g. with Debian cowbuilder)
     my $home = File::HomeDir->my_home // '';
     my $log4perl_user_conf_file = path( $home . '/.log4config-model' );
 
-    my $fallback_conf           = << 'EOC';
-log4perl.rootLogger=WARN, Screen
+    my $fallback_conf_file = path($INC{"Config/Model.pm"})
+        ->parent->child("Model/log4perl.conf") ;
 
-# user message about deprecation issues
-log4perl.logger.Model.Legacy = INFO, SimpleScreen
-log4perl.additivity.Model.Legacy = 0
 
-# messages for users, aims to replace calls to warn for warnings or fix messages
-log4perl.logger.User = WARN, SimpleScreen
-log4perl.additivity.User = 0
+    my $log4perl_file =
+        $force_default_log                ? $fallback_conf_file # for tests
+      : $log4perl_user_conf_file->is_file ? $log4perl_user_conf_file
+      : $log4perl_syst_conf_file->is_file ? $log4perl_syst_conf_file
+      :                                     $fallback_conf_file;
+    my %log4perl_conf =
+        map { split /\s*=\s*/,$_,2; }
+        grep { chomp; ! /^\s*#/ } $log4perl_file->lines;
 
-log4perl.appender.Screen        = Log::Log4perl::Appender::Screen
-log4perl.appender.Screen.stderr = 0
-log4perl.appender.Screen.layout = Log::Log4perl::Layout::PatternLayout
-log4perl.appender.Screen.layout.ConversionPattern = %M %m (line %L)%n
-
-log4perl.appender.SimpleScreen        = Log::Log4perl::Appender::Screen
-log4perl.appender.SimpleScreen.stderr = 1
-log4perl.appender.SimpleScreen.layout = Log::Log4perl::Layout::PatternLayout
-log4perl.appender.SimpleScreen.layout.ConversionPattern = %p: %m%n
-
-log4perl.oneMessagePerAppender = 1
-EOC
-
-    my @log4perl_conf_lines =
-        $log4perl_user_conf_file->is_file ? $log4perl_user_conf_file->lines
-      : $log4perl_syst_conf_file->is_file ? $log4perl_syst_conf_file->lines
-      :                                     split /\n/, $fallback_conf;
-    my %log4perl_conf = map { split /\s*=\s*/,$_,2; } grep { chomp; ! /^\s*#/ } @log4perl_conf_lines;
-
-    if (defined $args->{log_level}) {
-        $log4perl_conf{'log4perl.logger'} = $args->{log_level}.', Screen';
+    my $verbose = $args{verbose};
+    if (defined $verbose) {
+        my @loggers = ref $verbose ? @$verbose : $verbose;
+        foreach my $logger (@loggers) {
+            $log4perl_conf{"log4perl.logger.Verbose.$logger"} = "INFO, PlainMsgOnScreen";
+        }
     }
 
     Log::Log4perl::init(\%log4perl_conf);
 
+    return \%log4perl_conf; # for tests
 }
 
 sub BUILD {
     my $self = shift;
-    $self->initialize_log4perl(shift) unless Log::Log4perl->initialized();
+    my $args = shift;
+    initialize_log4perl(verbose => $args->{verbose}) unless Log::Log4perl->initialized();
 }
 
 sub show_legacy_issue {
@@ -514,8 +507,8 @@ sub normalize_class_parameters {
             my $implicit = defined $name_match->{name_match} ? '' : 'implicit ';
             unshift @$accept_info, $name_match;    # put data back in list
             $name_match = delete $name_match->{name_match} || '.*';
-            warn "class $config_class_name: name_match ($implicit$name_match)",
-                " in accept is deprecated\n";
+            $logger->warn("class $config_class_name: name_match ($implicit$name_match)",
+                " in accept is deprecated");
         }
 
         push @accept_list, $name_match;
@@ -527,7 +520,7 @@ sub normalize_class_parameters {
 
     # check for duplicate in @element_list.
     my %check_list;
-    map { $check_list{$_}++ } @element_list;
+    foreach (@element_list) { $check_list{$_}++ };
     my @extra = grep { $check_list{$_} > 1 } keys %check_list;
     if (@extra) {
         Config::Model::Exception::ModelDeclaration->throw(
@@ -562,7 +555,7 @@ sub normalize_class_parameters {
                 $self->handle_experience_permission( $config_class_name, $info );
 
                 # copy in element data *after* legacy translation
-                map { $model->{element}{$_} = dclone($info); } @element_names;
+                foreach (@element_names) { $model->{element}{$_} = dclone($info); };
             }
 
             # move some information into element declaration (without clobberring)
@@ -722,7 +715,9 @@ sub translate_legacy_backend_info {
     # merge write_config spec in rw_config
     if ($model->{write_config}) {
         $self->show_legacy_issue("$config_class_name: write_config specification is deprecated, please merge with read_config and move in rw_config", 'warn');
-        map {$model->{rw_config}{$_} = $model->{write_config}{$_} } keys %{$model->{write_config}} ;
+        foreach (keys %{$model->{write_config}}) {
+            $model->{rw_config}{$_} = $model->{write_config}{$_}
+        }
         delete $model->{write_config};
     }
 
@@ -839,13 +834,13 @@ sub translate_compute_info {
 
         my ( $user_formula, %var ) = @$compute_info;
         my $replace_h;
-        map { $replace_h = delete $var{$_} if ref( $var{$_} ) } keys %var;
+        foreach ( keys %var ) { $replace_h = delete $var{$_} if ref( $var{$_} ) };
 
         # cleanup user formula
         $user_formula =~ s/\$(\w+)\{/\$replace{/g;
 
         # cleanup variable
-        map { s/\$(\w+)\{/\$replace{/g } values %var;
+        foreach ( values %var ) { s/\$(\w+)\{/\$replace{/g };
 
         # change the hash *in* the info structure
         $info->{$new_name} = {
@@ -1101,7 +1096,7 @@ sub translate_follow_arg {
         # translate legacy follow arguments ['warp1','warp2',...]
         my $follow = {};
         my $idx    = 0;
-        map { $follow->{ 'f' . $idx++ } = $_ } @$raw_follow;
+        foreach ( @$raw_follow ) { $follow->{ 'f' . $idx++ } = $_ } ;
         return $follow;
     }
     elsif ( defined $raw_follow ) {
@@ -1234,7 +1229,7 @@ sub include_one_class {
     my $include_class = shift || croak "include_class: undef include_class param";
     my $include_after = shift;
 
-    get_logger('Model')->info("class $class_name includes $include_class");
+    get_logger('Model')->debug("class $class_name includes $include_class");
 
     if (    defined $include_class
         and defined $self->{included_class}{$class_name}{$include_class} ) {
@@ -1285,7 +1280,7 @@ sub include_one_class {
                     . " (included from $include_class)" );
         }
     }
-    get_logger('Model')->info("class $class_name include $include_class done");
+    get_logger('Model')->debug("class $class_name include $include_class done");
 }
 
 # load a model from file. See comments around raw_models attribute for explanations
@@ -1846,7 +1841,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -2671,6 +2666,27 @@ the various exception classes provided with C<Config::Model>.
 
 See L<cme/Logging>
 
+=head2 initialize_log4perl
+
+This method can be called to load L<Log::Log4perl> configuration from
+C<~/.log4config-model>, or from L</etc/log4config-model.conf> files or from
+L<default configuration|https://github.com/dod38fr/config-model/blob/master/lib/Config/Model/log4perl.conf>.
+
+Accepts C<verbose> parameter with a list of log classes that are added
+to the log4perl configuration read above.
+
+For instance, with C<< verbose => 'Loader' >>, log4perl is initialised with
+
+ log4perl.logger.Verbose.Loader = INFO, PlainMsgOnScreen
+
+Likewise, with C<< verbose => [ 'Loader', 'Foo' ] >>,
+log4perl is initialised with:
+
+ log4perl.logger.Verbose.Loader = INFO, PlainMsgOnScreen
+ log4perl.logger.Verbose.Foo    = INFO, PlainMsgOnScreen
+
+Currently, this module supports only C<Loader> as verbose parameters.
+
 =head1 BUGS
 
 Given Murphy's law, the author is fairly confident that you will find
@@ -2695,6 +2711,8 @@ In alphabetical order:
 
   Harley Pig
 
+  Ilya Arosov
+
   Jose Luis Perez Diez
 
   Krzysztof Tyszecki
@@ -2786,10 +2804,6 @@ L<Config::Model::Backend::PlainFile> <- L<Config::Model::Backend::Any>
 
 L<Config::Model::Backend::ShellVar> <- L<Config::Model::Backend::Any>
 
-=item *
-
-L<Config::Model::Backend::Yaml> <- L<Config::Model::Backend::Any>
-
 =back
 
 =head2 Model utilities
