@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Any;
-$Config::Model::Backend::Any::VERSION = '2.117';
+$Config::Model::Backend::Any::VERSION = '2.133';
 use Carp;
 use strict;
 use warnings;
@@ -21,7 +21,7 @@ use Log::Log4perl qw(get_logger :levels);
 my $logger = get_logger("Backend");
 
 has 'name' => ( is => 'ro', default => 'unknown', );
-has 'annotation' => ( is => 'ro', isa => 'Bool', default => 0 );
+has [qw/annotation auto_create auto_delete/] => ( is => 'ro', isa => 'Bool', default => 0 );
 has 'node' => (
     is       => 'ro',
     isa      => 'Config::Model::Node',
@@ -32,10 +32,6 @@ has 'node' => (
 
 sub skip_open { return 0; }
 
-sub suffix {
-    return undef;
-}
-
 sub read {
     my $self = shift;
     my $err  = "Internal error: read not defined in backend $self->{name}.";
@@ -57,6 +53,7 @@ sub read_global_comments {
 
     my $cc_re = length $cc > 1 ? "[$cc]" : $cc;
     my @global_comments;
+    my @global_comment_lines;
 
     while ( defined( my $l = shift @$lines ) ) {
         next if $l =~ /^$cc_re{2}/;    # remove comments added by Config::Model
@@ -74,17 +71,26 @@ sub read_global_comments {
 
         my ( $data, $comment ) = split /\s*$cc_re\s?/, $l, 2;
 
-        push @global_comments, $comment if defined $comment;
+        if (defined $comment) {
+            push @global_comment_lines, $l;
+            push @global_comments, $comment;
+        }
 
-        if ( $l =~ /^\s*$/ or $data ) {
+        if ( $l =~ /^\s*$/ ) {
+            # we indeed had global comments which are now finished by
+            # a blank line.  Store them and bail out
             if (@global_comments) {
                 $self->node->annotation(@global_comments);
-                $logger->debug("Setting global comment with @global_comments");
+                $logger->debug("Setting global comment with @global_comments on ", $self->node->name);
             }
-            # put back any data and comment
-            unshift @$lines, $l unless $l =~ /^\s*$/;
+            # stop global comment at first blank line
+            last;
+        }
+        if ( $data ) {
+            # The comment found is not global, put back line and any captured comment
+            unshift @$lines, @global_comment_lines, $l;
 
-            # stop global comment at first blank or non comment line
+            # stop global comment
             last;
         }
     }
@@ -123,7 +129,22 @@ sub associates_comments_with_data {
 }
 
 sub write_global_comment {
-    my ( $self, $ioh, $cc ) = @_;
+    goto &write_global_comments;
+}
+
+sub write_global_comments {
+    my $self = shift;
+    my ($ioh, $cc);
+    if (ref($_[0])) {
+        my ($package, $filename, $line) = caller;
+        $logger->warn("write_global_comments: io_handle parameter is deprecated ($filename: $line)");
+        ($ioh, $cc) = @_;
+    }
+    else {
+        ( $cc ) = @_;
+    }
+
+    croak "write_global_comments: no comment char specified" unless $cc;
 
     # no need to mention 'cme list' if current application is found
     my $app = $self->node->instance->application ;
@@ -150,8 +171,17 @@ sub write_global_comment {
     return $res;
 }
 
+# $cc can be undef when writing a list on a single line
 sub write_data_and_comments {
-    my ( $self, $ioh, $cc, @data_and_comments ) = @_;
+    my $self = shift;
+    my ($ioh, $cc, @data_and_comments);
+    if (not defined $_[0] or ref($_[0])) {
+        $logger->warn("write_data_and_comments: io_handle parameter is deprecated");
+        ($ioh, $cc, @data_and_comments) = @_;
+    }
+    else {
+        ( $cc, @data_and_comments ) = @_;
+    }
 
     my $res = '';
     while (@data_and_comments) {
@@ -183,7 +213,7 @@ Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -201,15 +231,14 @@ version 2.117
     # root       => './my_test',  # fake root directory, used for tests
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
-    # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object opened for read
+    # file_path  => Path::Tiny object for './my_test/etc/foo/foo.conf'
     # check      => yes|no|skip
 
-    return 0 unless defined $args{io_handle} ; # or die, your choice
+    return 0 unless $args{file_path}->exists ; # or die, your choice
 
     # read the file line by line
     # we assume the file contain lines like 'key=value'
-    foreach ($args{io_handle}->getlines) {
+    foreach ($args{file_path}->lines_utf8) {
         chomp ;   # remove trailing \n
         s/#.*// ; # remove any comment
         next unless /\S/; # skip blank line
@@ -229,21 +258,20 @@ version 2.117
     # root       => './my_test',  # fake root directory, used for tests
     # config_dir => /etc/foo',    # absolute path 
     # file       => 'foo.conf',   # file name
-    # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object opened for write
+    # file_path  => Path::Tiny object for './my_test/etc/foo/foo.conf'
     # check      => yes|no|skip
 
-    my $ioh = $args{io_handle} ;
-
     # read the content of the configuration tree
+    my @lines;
     foreach my $elt ($self->node->children) {
         # read the value from element $elt
         my $v = $self->node->grab_value($elt) ;
 
         # write value in file
-        $ioh->print(qq!$elt="$v"\n!) if defined $v ;
+        push @lines,qq!$elt="$v"\n! if defined $v ;
     }
 
+    $args{file_path}->spew_utf8(@lines);
     return 1;
  }
 
@@ -296,16 +324,15 @@ following methods:
 
 =item read
 
-C<read()> is called with the following parameters:
+C<read> is called with the following parameters:
 
  %custom_parameters,       # e.g. my_param   => 'my_value' in the example above
  object     => $obj,         # Config::Model::Node object
  root       => $root_dir,  # fake root directory, used for tests
  backend    => $backend,   # backend name
  config_dir => $read_dir,  # path below root
- file       => 'foo.conf',   # file name
- file_path  => $full_name, # full file name (root+path+file)
- io_handle  => $io_file    # IO::File object opened for read
+ file       => 'foo.conf', # file name
+ file_path  => $full_name, # Path::Tiny object
  check      => [yes|no|skip]
 
 The L<IO::File> object is undef if the file cannot be read.
@@ -314,12 +341,12 @@ This method must return 1 if the read was successful, 0 otherwise.
 
 Following the C<my_param> example above, C<%custom_parameters> contains
 C< ( 'my_param' , 'my_value' ) >, so C<read()> is called with
-C<root>, C<config_dir>, C<file_path>, C<io_handle> B<and>
+C<root>, C<config_dir>, C<file_path> B<and>
 C<<  my_param   => 'my_value' >>.
 
 =item write
 
-C<write()> is called with the following parameters:
+C<write> is called with the following parameters:
 
  %$custom_parameters,         # e.g. my_param   => 'my_value' in the example above
  object      => $obj,         # Config::Model::Node object
@@ -330,7 +357,6 @@ C<write()> is called with the following parameters:
  config_dir  => $write_dir,   # override from instance
  file        => 'foo.conf',   # file name
  file_path   => $full_name, # full file name (root+path+file)
- io_handle   => $fh,          # IO::File object
  write       => 1,            # always
  check       => [ yes|no|skip] ,
  backup      => [ undef || '' || suffix ] # backup strategy required by user
@@ -339,22 +365,6 @@ The L<IO::File> object is undef if the file cannot be written to.
 
 This method must return 1 if the write was successful, 0 otherwise
 
-If C<io_handle> is defined, the backup has already been done before
-opening the config file. If C<io_handle> is not defined, there's not
-enough information in the model to read the configuration file and
-create the backup. Your C<write()> method will have to do the backup
-requested by user.
-
-When both C<config_dir> and C<file> are specified,
-the L<backend manager|Config::Model::BackendMgr>
-opens the configuration file for write (and thus clobbers it) before calling
-the C<write> call-back with the file handle with C<io_handle>
-parameter. C<write> should use this handle to write data in the target
-configuration file.
-
-If this behavior causes problem, the solution is to override
-C<skip_open> method in your backend to return C<1>.
-
 =back
 
 =head2 How to test your new backend
@@ -372,10 +382,33 @@ L<examples files|https://github.com/dod38fr/config-model/tree/master/t/model_tes
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => backend_name )
+=head2 new
 
-The constructor should be used only by
-L<Config::Model::Node>.
+The constructor should be used only by L<Config::Model::Node>.
+
+Parameter:
+
+=over
+
+=item node
+
+Calling node object. Node ref is weakened,
+
+=item name
+
+Backend name
+
+=item auto_create
+
+Boolean. Set to true to create the configuration file if this one is
+missing (default 0)
+
+=item auto_delete
+
+Boolean. Set to true to remove the configuration file if this one no
+longer contain configuration information. (default 0)
+
+=back
 
 =head1 Methods to override
 
@@ -403,9 +436,12 @@ Return the node (a L<Config::Model::Node>) holding this backend.
 
 Return the instance (a L<Config::Model::Instance>) holding this configuration.
 
-=head2 show_message( string )
+=head2 show_message
 
-Show a message to STDOUT (unless overridden). Delegated to L<Config::Model::Instance/"show_message( string )">.
+Parameters: C<( string )>
+
+Show a message to STDOUT (unless overridden).
+Delegated to L<Config::Model::Instance/"show_message">.
 
 =head2 read_global_comments
 
@@ -427,7 +463,8 @@ comment to begin with 'C<#>' or 'C<;>')
 
 Read the global comments (i.e. the first block of comments until the
 first blank or non comment line) and store them as root node
-annotation.
+annotation. Note that the global comment must be separated from the
+first data line by a blank line.
 
 Example:
 
@@ -468,16 +505,32 @@ Example:
   # @res is:
   # ( [ 'foo= 1', 'Foo comments' ] , [ 'Baz = 0' , 'Baz comments' ] )
 
-=head2 write_global_comments( io_handle , comment_char)
+=head2 write_global_comments
 
-Write global comments from configuration root annotation into the io_handle (if defined).
-Returns the string written to the io_handle.
+Return a string containing global comments using data from
+configuration root annotation.
 
-=head2 write_data_and_comments( io_handle , comment_char , data1, comment1, data2, comment2 ...)
+Requires one parameter: comment_char (e.g "#" or '//' )
 
-Write data and comments in the C<io_handle> (if defined). Comments are written before the data.
-Returns the string written to the io_handle. If a data is undef, the comment is written on its own
-line.
+Example:
+
+  my $str = $self->write_global_comments('#')
+
+=head2 write_data_and_comments
+
+Returns a string containing comments (stored in annotation) and
+corresponding data. Comments are written before the data. If a data is
+undef, the comment is written on its own line.
+
+Positional parameters are C<( comment_char , data1, comment1, data2, comment2 ...)>
+
+Example:
+
+ print $self->write_data_and_comments('#', 'foo', 'foo comment', undef, 'lone comment','bar')
+ # returns "# foo comment\nfoo\n#lon
+
+Use C<undef> as comment char if comments are not supported by the
+syntax of the configuration file. Comments will then be dropped.
 
 =head1 Replacing a custom backend
 
@@ -512,7 +565,6 @@ Dominique Dumont, (ddumont at cpan dot org)
 L<Config::Model>, 
 L<Config::Model::BackendMgr>, 
 L<Config::Model::Node>, 
-L<Config::Model::Backend::Yaml>, 
 
 =head1 AUTHOR
 
