@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::IniFile;
-$Config::Model::Backend::IniFile::VERSION = '2.117';
+$Config::Model::Backend::IniFile::VERSION = '2.133';
 use Carp;
 use Mouse;
 use 5.10.0;
@@ -32,10 +32,9 @@ sub read {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
-    return 0 unless defined $args{io_handle};    # no file to read
+    return 0 unless $args{file_path}->exists;    # no file to read
 
     my $section = '<top>';                       # dumb value used for logging
 
@@ -55,7 +54,7 @@ sub read {
     #in input file, would be written in the same way in the output
     #file.  Also, comments at the end of file are being ignored now.
 
-    my @lines = $args{io_handle}->getlines;
+    my @lines = $args{file_path}->lines_utf8;
 
     # try to get global comments (comments before a blank line)
     $self->read_global_comments( \@lines, $delimiter );
@@ -135,6 +134,7 @@ sub read {
     while ( my ( $k, $v ) = each %ini_comment ) {
         my $item = $obj->grab( step => $k, mode => 'loose' ) or next;
         $item = $item->fetch_with_id(0) if $item->get_type eq 'list';
+        $logger->debug("annotate '$v' on ", $item->location);
         $item->annotation($v);
     }
 
@@ -175,30 +175,33 @@ sub write {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
-    my $ioh       = $args{io_handle};
     my $node      = $args{object};
     my $delimiter = $args{comment_delimiter} || '#';
 
-    croak "Undefined file handle to write" unless defined $ioh;
+    croak "Undefined file handle to write" unless defined $args{file_path};
 
     # use the first char of the list as a comment delimeter
     my $cc = substr($delimiter,0,1);
     $args{comment_delimiter} = $cc;
 
-    $self->write_global_comment( $ioh, $cc );
+    my $res = '';
 
     # some INI file have a 'General' section mapped in root node
     my $top_class_name = $self->{reverse_section_map}{''};
     if ( defined $top_class_name ) {
         $logger->debug("writing class $top_class_name from reverse_section_map");
-        $self->write_data_and_comments( $ioh, $cc, "[$top_class_name]" );
+        $res .= $self->write_data_and_comments( $cc, "[$top_class_name]" );
     }
 
-    my $res = $self->_write(%args);
-    $ioh->print($res);
+    $res .= $self->_write(%args);
+    if ($res) {
+        $args{file_path}->spew_utf8($self->write_global_comment( $cc ) . $res);
+    }
+    elsif ($self->auto_delete) {
+        $args{file_path}->remove;
+    }
 }
 
 sub _write_list{
@@ -217,7 +220,7 @@ sub _write_list{
         my $v = join( $join_list, @v );
         if ( length($v) ) {
             $logger->debug("writing joined list elt $elt -> $v");
-            $res .= $self->write_data_and_comments( undef, $delimiter, "$elt$assign_with$v", $obj_note );
+            $res .= $self->write_data_and_comments( $delimiter, "$elt$assign_with$v", $obj_note );
         }
     }
     else {
@@ -227,7 +230,7 @@ sub _write_list{
             if ( length $v ) {
                 $logger->debug("writing list elt $elt -> $v");
                 $res .=
-                    $self->write_data_and_comments( undef, $delimiter, "$elt$assign_with$v",
+                    $self->write_data_and_comments( $delimiter, "$elt$assign_with$v",
                                                     $obj_note . $note );
             }
             else {
@@ -253,13 +256,13 @@ sub _write_check_list{
         my $v = join( $join_check_list, $obj->get_checked_list() );
         if ( length($v) ) {
             $logger->debug("writing check_list elt $elt -> $v");
-            $res .= $self->write_data_and_comments( undef, $delimiter, "$elt$assign_with$v", $obj_note );
+            $res .= $self->write_data_and_comments( $delimiter, "$elt$assign_with$v", $obj_note );
         }
     }
     else {
         foreach my $v ( $obj->get_checked_list() ) {
             $logger->debug("writing joined check_list elt $elt -> $v");
-            $res .= $self->write_data_and_comments( undef, $delimiter, "$elt$assign_with$v", $obj_note );
+            $res .= $self->write_data_and_comments( $delimiter, "$elt$assign_with$v", $obj_note );
         }
     }
     return $res;
@@ -282,7 +285,7 @@ sub _write_leaf{
     }
     if ( defined $v and length $v ) {
         $logger->debug("writing leaf elt $elt -> $v");
-        $res .= $self->write_data_and_comments( undef, $delimiter, "$elt$assign_with$v", $obj_note );
+        $res .= $self->write_data_and_comments( $delimiter, "$elt$assign_with$v", $obj_note );
     }
     else {
         $logger->trace("NOT writing undef or empty leaf elt");
@@ -305,7 +308,7 @@ sub _write_hash {
         my $subres = $self->_write( %$args, object => $hash_obj );
         if ($subres) {
             $res .= "\n"
-                . $self->write_data_and_comments( undef, $delimiter, "[$key]",
+                . $self->write_data_and_comments( $delimiter, "[$key]",
                                                   $obj_note . $note )
                 . $subres;
         }
@@ -332,7 +335,7 @@ sub _write_node {
         }
         my $c_name = $exception_name || $elt;
         $res .= "\n"
-            . $self->write_data_and_comments( undef, $delimiter, "[$c_name]", $obj_note )
+            . $self->write_data_and_comments( $delimiter, "[$c_name]", $obj_note )
             . $subres;
     }
     return $res;
@@ -412,7 +415,7 @@ Config::Model::Backend::IniFile - Read and write config as a INI file
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -514,7 +517,9 @@ parameter the comment may apply. Wrong estimations are possible.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => 'inifile' ) ;
+=head2 new
+
+Parameters: C<< ( node => $node_obj, name => 'inifile' ) >>
 
 Inherited from L<Config::Model::Backend::Any>. The constructor is
 called by L<Config::Model::BackendMgr>.
@@ -705,23 +710,21 @@ The C<assign_with> is used to control how the file is written back. E.g:
 
 =head1 Methods
 
-=head2 read ( io_handle => ... )
+=head2 read
 
-Of all parameters passed to this read call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-read. 
+Of all parameters passed to this read call-back, only C<file_path> is
+used. This parameter must be L<Path::Tiny> object.
 
-It can also be undef. In this case, C<read()> returns 0.
+It can also be undef. In this case, C<read> returns 0.
 
-When a file is read,  C<read()> returns 1.
+When a file is read, C<read> returns 1.
 
-=head2 write ( io_handle => ... )
+=head2 write
 
-Of all parameters passed to this write call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-write. 
+Of all parameters passed to this write call-back, only C<file_path> is
+used. This parameter must be a L<Path::Tiny> object.
 
-C<write()> returns 1.
+C<write> returns 1.
 
 =head1 AUTHOR
 
