@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::ShellVar;
-$Config::Model::Backend::ShellVar::VERSION = '2.117';
+$Config::Model::Backend::ShellVar::VERSION = '2.133';
 use Carp;
 use Mouse;
 use Config::Model::Exception;
@@ -47,13 +47,12 @@ sub read {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
-    return 0 unless defined $args{io_handle};    # no file to read
+    return 0 unless $args{file_path}->exists;    # no file to read
     my $check = $args{check} || 'yes';
 
-    my @lines = $args{io_handle}->getlines;
+    my @lines = $args{file_path}->lines_utf8;
 
     # try to get global comments (comments before a blank line)
     $self->read_global_comments( \@lines, '#' );
@@ -87,14 +86,10 @@ sub write {
     # config_dir => /etc/foo',    # absolute path
     # file       => 'foo.conf',   # file name
     # file_path  => './my_test/etc/foo/foo.conf'
-    # io_handle  => $io           # IO::File object
     # check      => yes|no|skip
 
-    my $ioh  = $args{io_handle};
     my $node = $args{object};
 
-    croak "Undefined file handle to write" unless defined $ioh;
-
     my @to_write;
 
     # Using Config::Model::ObjTreeScanner would be overkill
@@ -108,8 +103,11 @@ sub write {
     }
 
     if (@to_write) {
-        $self->write_global_comment( $ioh, '#' );
-        map { $self->write_data_and_comments( $ioh, '#', @$_ ); } @to_write;
+        my $res = $self->write_global_comment( '#' );
+        foreach my $line_ref (@to_write) {
+            $res .= $self->write_data_and_comments( '#', @$line_ref );
+        }
+        $args{file_path}->spew_utf8($res);
     }
 
     return 1;
@@ -134,7 +132,7 @@ Config::Model::Backend::ShellVar - Read and write config as a C<SHELLVAR> data s
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -185,28 +183,26 @@ contains C<'a','b'>.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => 'shellvar' ) ;
+=head2 new
+
+Parameters: C<< ( node => $node_obj, name => 'shellvar' ) >>
 
 Inherited from L<Config::Model::Backend::Any>. The constructor is
 called by L<Config::Model::BackendMgr>.
 
-=head2 read ( io_handle => ... )
+=head2 read
 
-Of all parameters passed to this read call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-read. 
+Of all parameters passed to this read call-back, only C<file_path> is
+used.
 
-It can also be undef. In which case C<read()> returns 0.
+When a file is read, C<read> returns 1.
 
-When a file is read,  C<read()> returns 1.
+=head2 write
 
-=head2 write ( io_handle => ... )
+Of all parameters passed to this write call-back, only C<file_path> is
+used.
 
-Of all parameters passed to this write call-back, only C<io_handle> is
-used. This parameter must be L<IO::File> object already opened for
-write. 
-
-C<write()> returns 1.
+C<write> returns 1.
 
 =head1 AUTHOR
 
