@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::BackendMgr;
-$Config::Model::BackendMgr::VERSION = '2.117';
+$Config::Model::BackendMgr::VERSION = '2.133';
 use Mouse;
 use strict;
 use warnings;
@@ -18,10 +18,6 @@ use 5.10.1;
 
 use Config::Model::Exception;
 use Data::Dumper;
-use File::Path;
-use File::Copy;
-use File::HomeDir;
-use IO::File;
 use Storable qw/dclone/;
 use Scalar::Util qw/weaken reftype/;
 use Log::Log4perl qw(get_logger :levels);
@@ -57,14 +53,19 @@ sub _build_backend_obj {
     my $self = shift;
 
     my $backend = $self->rw_config->{backend};
-    warn("function parameter for a backend is deprecated. Please implement 'read' method in backend $backend")
+    $logger->warn("function parameter for a backend is deprecated. Please implement 'read' method in backend $backend")
         if $self->rw_config->{function};
     # try to load a specific Backend class
     my $f = $self->rw_config->{function} || 'read';
-    my $c = load_backend_class( $backend, $f );
+    my $c = $self->load_backend_class( $backend, $f );
 
-    no strict 'refs';
-    return $c->new( node => $self->node, name => $backend );
+    no strict 'refs'; ## no critic (ProhibitNoStrict)
+    return $c->new(
+        node => $self->node,
+        name => $backend,
+        auto_create => $self->rw_config->{auto_create},
+        auto_delete => $self->rw_config->{auto_delete},
+    );
 }
 
 has support_annotation => (
@@ -111,23 +112,14 @@ sub get_cfg_file_path {
     # config file override
     my $cfo = $args{config_file};
 
-    if ( defined $cfo and $cfo eq '-' and $w == 0 ) {
-        $logger->trace("auto_read: $args{backend} override target file is STDIN");
-        return ( 1, '-' );
-    }
-
     if ( defined $cfo ) {
-        my $override =  $args{root} ? path($args{root})->child($cfo) : path($cfo);
+        my $root_path = $args{root} // path('.');
+        my $override =  $root_path->child($cfo);
         my $mode = $w ? 'write' : 'read';
         $logger->trace("$args{backend} override target file is $override ($mode mode)");
         return ( 1, $override );
     }
 
-    Config::Model::Exception::Model->throw(
-        error  => "backend error: empty 'config_dir' parameter (and no config_file override)",
-        object => $self->node
-    ) unless defined $args{config_dir} or defined $self->config_dir;
-
     my ( $dir_ok, $dir ) = $self->get_cfg_dir_path(%args);
 
     if ( defined $args{file} ) {
@@ -137,35 +129,17 @@ sub get_cfg_file_path {
         return ( $dir_ok, $res );
     }
 
-    if (defined $args{suffix}) {
-        $logger->warn("Suffix method is deprecated. you can remove it from backend  $args{backend}");
-    }
     return 0;
 }
 
 sub open_read_file {
     my ($self, $file_path) = @_;
 
-    if ( $file_path eq '-' ) {
-        my $io = IO::Handle->new();
-        if ( $io->fdopen( fileno(STDIN), "r" ) ) {
-            return $io;
-        }
-        else {
-            return;
-        }
-    }
-
-    my $fh = new IO::File;
-    if ( -e $file_path ) {
+    if ( $file_path->is_file ) {
         $logger->debug("open_read_file: open $file_path for read");
-        $fh->open($file_path);
-        $fh->binmode(":utf8");
-
         # store a backup in memory in case there's a problem
-        $self->file_backup( [ $fh->getlines ] );
-        $fh->seek( 0, 0 );    # go back to beginning of file
-        return $fh;
+        $self->file_backup( [ $file_path->lines_utf8 ] );
+        return $file_path->filehandle("<", ":utf8");
     }
     else {
         return;
@@ -177,6 +151,7 @@ sub open_read_file {
 # New subroutine "load_backend_class" extracted - Thu Aug 12 18:32:37 2010.
 #
 sub load_backend_class {
+    my $self = shift;
     my $backend  = shift;
     my $function = shift;
 
@@ -214,7 +189,8 @@ sub load_backend_class {
 
     if (not defined  $class_to_load) {
         Config::Model::Exception::Model->throw(
-            error => "backend error: cannot find Perl class for backend $backend ",
+            object => $self->node,
+            error => "backend error: cannot find Perl class for backend: '$backend'",
         );
     };
     my $file_to_load = $c{$class_to_load};
@@ -258,7 +234,7 @@ sub read_config_data {
         $self->try_read_backend( $rw_config, $root_dir, $config_file_override, $check, $backend );
 
     Config::Model::Exception::ConfigFile::Missing->throw (
-        file   => $file,
+        file   => $file || "<unknown>",
         object => $self->node,
     ) unless $res or $auto_create_override or $auto_create;
 
@@ -270,8 +246,10 @@ sub read_config_sub_layer {
     my $layered_config = delete $rw_config->{default_layer};
     my $layered_read   = dclone $rw_config ;
 
-    map { my $lc = delete $layered_config->{$_}; $layered_read->{$_} = $lc if $lc; }
-        qw/file config_dir os_config_dir/;
+    foreach my $item ( qw/file config_dir os_config_dir/ ) {
+        my $lc = delete $layered_config->{$item};
+        $layered_read->{$item} = $lc if $lc;
+    }
 
     Config::Model::Exception::Model->throw(
         error => "backend error: unexpected default_layer parameters: "
@@ -318,19 +296,21 @@ sub try_read_backend {
         config_file => $config_file_override
     );
 
-    my ( $res, $file_path, $error );
-
     my $backend_obj = $self->backend_obj();
 
-    my ($file_ok, $fh, $suffix);
-    $suffix = $backend_obj->suffix if $backend_obj->can('suffix');
-    ( $file_ok, $file_path ) = $self->get_cfg_file_path(
+    if ($backend_obj->can('suffix')) {
+        $logger->warn("suffix method is deprecated. you can remove it from backend $backend");
+    }
+
+    my ( $file_ok, $file_path ) = $self->get_cfg_file_path(
         @read_args,
-        suffix => $suffix,
         skip_compute => $backend_obj->skip_open,
     );
-    $fh = $self->open_read_file($file_path)
-        if $file_ok and not $backend_obj->skip_open;
+
+    my $fh;
+    if (not $backend_obj->skip_open and $file_ok) {
+        $fh = $self->open_read_file($file_path) ;
+    }
 
     my $f = $self->rw_config->{function} || 'read';
     if ($logger->is_info) {
@@ -338,15 +318,17 @@ sub try_read_backend {
         $logger->info( "Read with $backend " . reftype($backend_obj) . "::$f".$fp);
     }
 
+    my $res;
+
     eval {
         $res = $backend_obj->$f(
             @read_args,
             file_path => $file_path,
-            io_handle => $fh,
+            io_handle => Config::Model::DeprecatedHandle->new($fh),
             object    => $self->node,
         );
     };
-    $error = $@;
+    my $error = $@;
 
     # catch eval error
     if ( ref($error) and $error->isa('Config::Model::Exception::Syntax') ) {
@@ -361,7 +343,7 @@ sub try_read_backend {
         die $error ;
     }
     elsif ( $error ) {
-        die "Backend error: $error";
+        die "Backend $backend failed to read $file_path: $error";
     }
 
     # only backend based on C::M::Backend::Any can support annotations
@@ -404,7 +386,7 @@ sub auto_write_init {
 
     my $wb;
     my $f = $rw_config->{function} || 'write';
-    my $c = load_backend_class( $backend, $f );
+    my $backend_class = $self->load_backend_class( $backend, $f );
     my $location = $self->node->name;
     my $node = $self->node;     # closure
 
@@ -415,16 +397,21 @@ sub auto_write_init {
         my $force_delete = delete $cb_args{force_delete} ;
         $logger->debug( "write cb ($backend) called for $location ", $force_delete ? '' : ' (deleted)' );
         my $backend_obj = $self->backend_obj();
-        my $suffix = $backend_obj->suffix if $backend_obj->can('suffix');
-        my ( $file_ok, $file_path, $fh );
-        ( $file_ok, $file_path, $fh ) =
-            $self->open_file_to_write( $backend, suffix => $suffix, @wr_args, %cb_args )
-            unless $c->skip_open;
+
+        my ($fh, $file_ok, $file_path );
+
+        if (not $backend_class->skip_open) {
+            ( $file_ok, $file_path ) = $self->get_cfg_file_path( @wr_args, %cb_args);
+        }
+
+        if ($file_ok) {
+            $fh = $self->open_file_to_write( $backend, $file_path, delete $cb_args{backup} );
+        }
 
         # override needed for "save as" button
         my %backend_args = (
             @wr_args,
-            io_handle => $fh,
+            io_handle => Config::Model::DeprecatedHandle->new($fh),
             file_path => $file_path,
             object    => $node,
             %cb_args            # override from user
@@ -437,11 +424,12 @@ sub auto_write_init {
         else {
             $res = eval { $backend_obj->$f( %backend_args ); };
             my $error = $@;
-            $logger->warn( "write backend $backend $c" . '::' . "$f failed: $error" ) if $error;
-            $self->close_file_to_write( $error, $fh, $file_path, $rw_config->{file_mode} );
+            $logger->error( "write backend $backend $backend_class" . '::' . "$f failed: $error" )
+                if $error;
+            $self->close_file_to_write( $error, $file_path, $rw_config->{file_mode} );
 
             $self->auto_delete($file_path, \%backend_args)
-                if $rw_config->{auto_delete} and not $c->skip_open ;
+                if $rw_config->{auto_delete} and not $backend_class->skip_open ;
         }
 
         return defined $res ? $res : $@ ? 0 : 1;
@@ -457,6 +445,8 @@ sub auto_write_init {
 sub auto_delete {
     my ($self, $file_path, $args) = @_;
 
+    return unless $file_path;
+
     my $perl_data;
     $perl_data = $self->node->dump_as_data( full_dump => $args->{full_dump} // 0)
         if defined $self->node;
@@ -472,61 +462,42 @@ sub auto_delete {
 
 
 sub open_file_to_write {
-    my ( $self, $backend, %args ) = @_;
+    my ( $self, $backend, $file_path, $backup ) = @_;
 
-    my $backup    = delete $args{backup};
     my $do_backup = defined $backup;
     $backup ||= 'old';    # use old only if defined
     $backup = '.' . $backup unless $backup =~ /^\./;
 
-    my ( $file_ok, $file_path ) = $self->get_cfg_file_path(%args);
+    # make sure that parent dir exists before creating file
+    $file_path->parent->mkpath;
 
-    if ( $file_ok and $file_path eq '-' ) {
-        my $io = IO::Handle->new();
-        if ( $io->fdopen( fileno(STDOUT), "w" ) ) {
-            return ( 1, '-', $io );
-        }
-        else {
-            return ( 0, '-' );
-        }
-    }
-    elsif ($file_ok) {
-        my $file = path($file_path);
-        if ( $do_backup and $file->is_file ) {
-            $file->copy( $file_path . $backup ) or die "Backup copy failed: $!";
-        }
-        $logger->debug("$backend backend opened file $file_path to write");
-        my $fh = $file->openw_utf8;
-        return ( $file_ok, $file_path, $fh );
-    }
-    else {
-        return ( 0, $file_path );
+    if ( $do_backup and $file_path->is_file ) {
+        $file_path->copy( $file_path.$backup ) or die "Backup copy failed: $!";
     }
+
+    $logger->debug("$backend backend opened file $file_path to write");
+    return $file_path->filehandle(">",":utf8");
 }
 
 sub close_file_to_write {
-    my ( $self, $error, $fh, $file_path, $file_mode ) = @_;
+    my ( $self, $error, $file_path, $file_mode ) = @_;
 
     return unless defined $file_path;
 
     if ($error) {
-
         # restore backup and display error
-        my $data = $self->file_backup;
-        $logger->debug(
-            "Error during write, restoring backup in $file_path with " . scalar @$data . " lines" );
-        $fh->seek( 0, 0 );    # go back to beginning of file
-        $fh->print(@$data);
-        $fh->close;
+        $logger->warn("Error during write, restoring backup data in $file_path" );
+        $file_path->spew_utf8( $self->file_backup );
         $error->rethrow if ref($error) and $error->can('rethrow');
         die $error;
     }
 
-    $fh->close;
-    path($file_path)->chmod($file_mode) if $file_mode;
+    # TODO: move chmod in a backend role
+    $file_path->chmod($file_mode) if $file_mode;
 
+    # TODO: move in a backend role
     # check file size and remove empty files
-    unlink($file_path) if -z $file_path and not -l $file_path;
+    $file_path->remove if -z $file_path and not -l $file_path;
 }
 
 sub is_auto_write_for_type {
@@ -537,6 +508,34 @@ sub is_auto_write_for_type {
 
 __PACKAGE__->meta->make_immutable;
 
+package Config::Model::DeprecatedHandle;
+$Config::Model::DeprecatedHandle::VERSION = '2.133';
+our $AUTOLOAD;
+
+sub new {
+    my $class = shift;
+    my $fh = shift;
+
+    return defined $fh ? bless \$fh, $class : undef;
+}
+
+sub AUTOLOAD {
+    my $self = shift;
+    my $f = $AUTOLOAD;
+    $f =~ s/.*:://;
+    my ($package, $filename, $line) = caller;
+
+    # $$self may not be defined during destruction
+    if ($$self and $self->can($f)) {
+        $logger->warn(
+            "io_handle backend parameter is deprecated, ",
+            "please use file_path parameter. ",
+            "(called $f at $filename:$line)"
+        ) unless $package eq "Config::Model::BackendMgr";
+
+        $$self->$f(@_);
+    }
+}
 1;
 
 # ABSTRACT: Load configuration node on demand
@@ -553,11 +552,13 @@ Config::Model::BackendMgr - Load configuration node on demand
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
  # Use BackendMgr to write data in Yaml file
+ # This example requires Config::Model::Backend::Yaml which is now
+ # shipped outside of Config::Model. Please get it on CPAN
  use Config::Model;
 
  # define configuration tree object
@@ -576,14 +577,12 @@ version 2.117
     name => "MyClass",
 
     # rw_config spec is used by Config::Model::BackendMgr
-    rw_config => [
-        {
-            backend     => 'yaml',
-            config_dir  => '/tmp/',
-            file        => 'my_class.yml',
-            auto_create => 1,
-        },
-    ],
+    rw_config => {
+        backend     => 'yaml',
+        config_dir  => '/tmp/',
+        file        => 'my_class.yml',
+        auto_create => 1,
+    },
 
     element => [
         [qw/foo bar/] => {
@@ -709,9 +708,6 @@ name. For instance, with C<file> set to C<&element-&index.conf>:
    bar      # hash index
      nodeB  # values of nodeB are  stored in service.bar.conf
 
-Alternatively, C<file> can be set to C<->, in which case, the
-configuration is read from STDIN.
-
 =item file_mode
 
 C<file_mode> parameter can be used to set the mode of the written
@@ -738,11 +734,11 @@ specifies default values. For instance, this is used by OpenSSH to
 specify a global configuration file (C</etc/ssh/ssh_config>) that is
 overridden by user's file:
 
-	'default_layer' => {
-            os_config_dir => { 'darwin' => '/etc' },
-            config_dir    => '/etc/ssh',
-            file          => 'ssh_config'
-        }
+ default_layer => {
+    os_config_dir => { 'darwin' => '/etc' },
+    config_dir    => '/etc/ssh',
+    file          => 'ssh_config'
+ }
 
 Only the 3 above parameters can be specified in C<default_layer>.
 
@@ -752,12 +748,12 @@ By default, an exception is thrown if no read was
 successful. This behavior can be overridden by specifying
 C<< auto_create => 1 >> in one of the backend specification. For instance:
 
-    rw_config  => {
-        backend => 'IniFile',
-        config_dir => '/tmp',
-        file  => 'foo.conf',
-        auto_create => 1
-    },
+ rw_config  => {
+     backend => 'IniFile',
+     config_dir => '/tmp',
+     file  => 'foo.conf',
+     auto_create => 1
+ },
 
 Setting C<auto_create> to 1 is necessary to create a configuration
 from scratch
@@ -775,11 +771,11 @@ in their documentation.
 
 For instance:
 
-   rw_config => {
-       backend     => 'yaml',
-       config_dir  => '/tmp/',
-       file        => 'my_class.yml',
-   },
+ rw_config => {
+     backend     => 'yaml',
+     config_dir  => '/tmp/',
+     file        => 'my_class.yml',
+ },
 
 See L<Config::Model::Backend::Yaml> for more details for this backend.
 
@@ -795,18 +791,6 @@ By default, configurations files are read from the directory specified
 by C<config_dir> parameter specified in the model. You may override the
 C<root> directory for test.
 
-=head1 CAVEATS
-
-When both C<config_dir> and C<file> are specified, this class
-write-opens the configuration file (and thus clobber it) before calling
-the C<write> call-back and pass the file handle with C<io_handle>
-parameter. C<write> should use this handle to write data in the target
-configuration file.
-
-If this behavior causes problem (e.g. with augeas backend), the
-solution is either to set C<file> to undef or an empty string in the
-C<rw_config> specification.
-
 =head1 Methods
 
 =head2 support_annotation
