@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::DumpAsData;
-$Config::Model::DumpAsData::VERSION = '2.117';
+$Config::Model::DumpAsData::VERSION = '2.133';
 use Carp;
 use strict;
 use warnings;
@@ -31,6 +31,7 @@ sub dump_as_data {
     my $skip_aw = delete $args{skip_auto_write} || '';
     my $auto_v  = delete $args{auto_vivify}     || 0;
     my $ordered_hash_as_list = delete $args{ordered_hash_as_list};
+    my $to_boolean = delete $args{to_boolean} // sub {return $_[0] };
     $ordered_hash_as_list = 1 unless defined $ordered_hash_as_list;
 
     # mode and full_dump params are both accepted
@@ -40,8 +41,9 @@ sub dump_as_data {
 
     my $std_cb = sub {
         my ( $scanner, $data_r, $obj, $element, $index, $value_obj ) = @_;
-
-        $$data_r = $value_obj->fetch(mode => $fetch_mode);
+        my $v = $value_obj->fetch(mode => $fetch_mode);
+        # transform boolean type in boolean object
+        $$data_r = $value_obj->value_type eq 'boolean' ? $to_boolean->($v) : $v;
     };
 
     my $check_list_element_cb = sub {
@@ -256,7 +258,7 @@ Config::Model::DumpAsData - Dump configuration content as a perl data structure
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -316,20 +318,24 @@ of a configuration tree in perl data structure.
 The perl data structure is a hash of hash. Only
 L<CheckList|Config::Model::CheckList> content is stored in an array ref.
 
+User can pass a sub reference to apply to values of boolean type. This
+sub can be used to convert the value to an object representing a
+boolean like L<boolean>. (since 2.129)
+
 Note that undefined values are skipped for list element. I.e. if a
 list element contains C<('a',undef,'b')>, the data structure then
 contains C<'a','b'>.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( )
+=head2 new
 
 No parameter. The constructor should be used only by
 L<Config::Model::Node>.
 
 =head1 Methods
 
-=head2 dump_as_data(...)
+=head2 dump_as_data
 
 Return a perl data structure
 
@@ -385,11 +391,20 @@ special key that specifies the order of keys. E.g.:
    B => 'bar', A => 'foo', C => 'baz'
   }
 
+=item to_boolean
+
+Sub reference to map a value of type boolean to a boolean class (since
+2.129). For instance:
+
+ to_boolean => sub { boolean($_[0]); }
+
+Default is C<sub { return $_[0] }>
+
 =back
 
 =head1 Methods
 
-=head2 dump_annotations_as_pod(...)
+=head2 dump_annotations_as_pod
 
 Return a string formatted in pod (See L<perlpod>) with the annotations.
 
