@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.117';
+$Config::Model::Instance::VERSION = '2.133';
 #use Scalar::Util qw(weaken) ;
 use strict;
 
@@ -236,17 +236,14 @@ has [qw/name application backend backend_arg backup/] => (
     isa => 'Maybe[Str]',
 );
 
-has 'root_dir' => (
-    is => 'bare',
-    isa => 'Maybe[Str]',
-);
+subtype 'RootPath' => as 'Maybe[Path::Tiny]' ;
+coerce 'RootPath' => from 'Str' => via sub { defined $_ ?  Path::Tiny::path($_) : undef ; } ;
 
-sub root_dir {
-    my $self = shift;
-    my $d = $self->{root_dir} // '';
-    # add trailing '/' if it's missing
-    return $d && $d !~ m!/$! ? "$d/" : $d;
-}
+has 'root_dir' => (
+    is => 'ro',
+    isa => 'RootPath',
+    coerce => 1
+);
 
 sub read_root_dir {
     my $self = shift;
@@ -392,9 +389,9 @@ sub modify {
 
 sub load {
     my $self   = shift;
-    my $loader = Config::Model::Loader->new;
+    my $loader = Config::Model::Loader->new( start_node => $self->{tree} );
     my %args   = @_ eq 1 ? ( step => $_[0] ) : @_;
-    $loader->load( node => $self->{tree}, %args );
+    $loader->load( %args );
     return $self;
 }
 
@@ -454,6 +451,16 @@ sub notify_change {
     $self->on_change_cb->( %args );
 }
 
+sub _truncate {
+    my @lines = @_;
+    foreach my $l (@lines) {
+        next unless defined $l;
+        $l =~ s/\n/ /g;
+        substr ($l, 60) = '[...]' if length $l > 60; # limit string length
+    }
+    return @lines;
+}
+
 sub list_changes {
     my $self = shift;
     my $l    = $self->changes;
@@ -463,13 +470,7 @@ sub list_changes {
         my $path = $c->{path} ;
 
         my $vt = $c->{value_type} || '';
-        my ( $o, $n ) = map {
-            if (defined $_) {
-                s/\n/ /g;
-                substr ($_, 60) = '[...]' if length $_ > 60; # limit string length
-            }
-            $_;
-        } ( $c->{old}, $c->{new} );
+        my ( $o, $n ) = _truncate( $c->{old}, $c->{new} );
 
         my $note = $c->{note} ? " # $c->{note}" : '';
 
@@ -527,11 +528,11 @@ sub write_back {
 
     foreach my $k ( keys %args ) {
         if ($k eq 'config_dir') {
-            $args{$_} ||= '';
-            $args{$_} .= '/' if $args{$_} and $args{$_} !~ m(/$);
+            $args{$k} ||= '';
+            $args{$k} .= '/' if $args{$k} and $args{$k} !~ m(/$);
         }
         elsif ( $k !~ /^(config_file|backend)$/ ) {
-            croak "write_back: wrong parameters $_";
+            croak "write_back: wrong parameters $k";
         }
     }
 
@@ -661,7 +662,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -726,8 +727,9 @@ Constructor parameters are:
 =item root_dir
 
 Pseudo root directory where to read I<and> write configuration
-files. Configuration directory specified in model or with
-C<config_dir> option is appended to this root directory
+files (L<Path::Tiny> object or string). Configuration directory
+specified in model or with C<config_dir> option is appended to this
+root directory
 
 =item root_path
 
@@ -737,7 +739,7 @@ directory if C<root_dir> is empty.
 =item config_dir
 
 Directory to read or write configuration file. This parameter must be
-supplied if not provided by the configuration model.
+supplied if not provided by the configuration model. (string)
 
 =item backend
 
@@ -805,25 +807,25 @@ C<< check => 'no' >> ).
 
 =head2 Manage configuration data
 
-=head2 modify ( ... )
+=head2 modify
 
-Calls L</"load(...)"> and then L</save>.
+Calls L</"load"> and then L</save>.
 
 Takes the same parameter as C<load> plus C<force_write> to force
 saving configuration file even if no value was modified (default is 0)
 
-=head2 load ( ... )
+=head2 load
 
 Load configuration tree with configuration data. See
-L<Config::Model::Loader/"load ( ... )"> for parameters.
+L<Config::Model::Loader/"load"> for parameters.
 Returns <$self>.
 
-=head2 save ( ... )
+=head2 save
 
 Save the content of the configuration tree to
 configuration files. (alias to C<write_back>)
 
-=head2 config_root()
+=head2 config_root
 
 Returns the L<root object|Config::Model::Node> of the configuration tree.
 
@@ -861,7 +863,9 @@ only for tests.
 
 Returns the number of warning found in the elements of this configuration instance.
 
-=head2 update( quiet => (0|1), %args )
+=head2 update
+
+Parameters: C<< ( quiet => (0|1), %args ) >>
 
 Try to run update command on all nodes of the configuration tree. Node
 without C<update> method are ignored. C<update> prints a message
@@ -878,7 +882,7 @@ Use the steps parameter to retrieve and returns the value of a leaf
 object from the configuration tree.  Forwarded to
 L<Config::Model::Role::Grab/grab_value>
 
-=head2 searcher ( )
+=head2 searcher
 
 Returns an object dedicated to search an element in the configuration
 model (respecting privilege level).
@@ -898,22 +902,24 @@ L<constructor arguments|Config::Model::Iterator/"Creating an iterator">.
 
 Returns the application name of the instance. (E.g C<popcon>, C<dpkg> ...)
 
-=head2 wizard_helper ( ... )
+=head2 wizard_helper
 
 Deprecated. Call L</iterator> instead.
 
 =head1 Internal methods
 
-=head2 name()
+=head2 name
 
 Returns the instance name.
 
-=head2 read_check()
+=head2 read_check
 
 Returns which kind of check is performed while reading configuration
 files. (see C<check> parameter in L</CONSTRUCTOR> section)
 
-=head2 show_message( string )
+=head2 show_message
+
+Parameters: C<( string )>
 
 Display the message on STDOUT unless a custom function was passed to
 C<on_message_cb> parameter.
@@ -923,52 +929,52 @@ C<on_message_cb> parameter.
 Destroy current configuration tree (with data) and returns a new tree with
 data (and annotations) loaded from disk.
 
-=head2 config_model()
+=head2 config_model
 
 Returns the model (L<Config::Model> object) of the configuration tree.
 
-=head2 annotation_saver()
+=head2 annotation_saver
 
 Returns the object loading and saving annotations. See
 L<Config::Model::Annotation> for details.
 
-=head2 preset_start ()
+=head2 preset_start
 
 All values stored in preset mode are shown to the user as default
 values. This feature is useful to enter configuration data entered by
 an automatic process (like hardware scan)
 
-=head2 preset_stop ()
+=head2 preset_stop
 
 Stop preset mode
 
-=head2 preset ()
+=head2 preset
 
 Get preset mode
 
-=head2 preset_clear()
+=head2 preset_clear
 
 Clear all preset values stored.
 
-=head2 layered_start ()
+=head2 layered_start
 
 All values stored in layered mode are shown to the user as default
 values. This feature is useful to enter configuration data entered by
 an automatic process (like hardware scan)
 
-=head2 layered_stop ()
+=head2 layered_stop
 
 Stop layered mode
 
-=head2 layered ()
+=head2 layered
 
 Get layered mode
 
-=head2 layered_clear()
+=head2 layered_clear
 
 Clear all layered values stored.
 
-=head2 get_data_mode 
+=head2 get_data_mode
 
 Returns 'normal' or 'preset' or 'layered'. Does not take into account
 initial_load.
@@ -993,11 +999,19 @@ clears this value once the first read is done.
 
 Get initial_load mode
 
-=head2 data( kind, [data] )
+=head2 data
 
-The data method provide a way to store some arbitrary data in the
+This method provides a way to store some arbitrary data in the
 instance object.
 
+E.g:
+
+  $instance->data(foo => 'bar');
+
+Later:
+
+  my $foo = $instance->data('foo'); # $foo contains 'bar'
+
 =head1 Read and write backend features
 
 Usually, a program based on config model must first create the
@@ -1007,21 +1021,30 @@ This feature enables you to declare with the model a way to load
 configuration data (and to write it back). See
 L<Config::Model::BackendMgr> for details.
 
-=head2 backend()
+=head2 backend
 
 Get the preferred backend method for this instance (as passed to the
 constructor).
 
-=head2 root_dir()
+=head2 backend_arg
 
-Returns root directory where configuration data is read from or written to.
+Get L<cme> command line argument that may be used by the backend to
+get the configuration file. These method is typically used in the read
+and write method of a backend to know where is the configuration file
+to edit.
 
-=head2 root_path()
+=head2 root_dir
 
 Returns a L<Path::Tiny> object for the root directory where
 configuration data is read from or written to.
 
-=head2 register_write_back ( node_location )
+=head2 root_path
+
+Same as C<root_dir>
+
+=head2 register_write_back
+
+Parameters: C<( node_location )>
 
 Register a node path that is called back with
 C<write_back> method.
@@ -1029,17 +1052,16 @@ C<write_back> method.
 =head2 notify_change
 
 Notify that some data has changed in the tree. See
-L<Config::Model::AnyThing/notify_change(...)> for more details.
+L<Config::Model::AnyThing/notify_change> for more details.
 
-=head2 write_back ( ... )
+=head2 write_back
 
 In summary, save the content of the configuration tree to
 configuration files.
 
 In more details, C<write_back> trie to run all subroutines registered
 with C<register_write_back> to write the configuration information.
-(See L<Config::Model::BackendMgr>
-for details).
+(See L<Config::Model::BackendMgr> for details).
 
 You can specify here another config directory to write configuration
 data back with C<config_dir> parameter. This overrides the model
