@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::ObjTreeScanner;
-$Config::Model::ObjTreeScanner::VERSION = '2.126';
+$Config::Model::ObjTreeScanner::VERSION = '2.133';
 use strict;
 use Config::Model::Exception;
 use Scalar::Util qw/blessed/;
@@ -285,7 +285,7 @@ Config::Model::ObjTreeScanner - Scan config tree and perform call-backs for each
 
 =head1 VERSION
 
-version 2.126
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -387,7 +387,7 @@ ref may be used to store whatever result you want.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( ... )
+=head2 new
 
 One way or another, the ObjTreeScanner object must be able to find all
 callback for all the items of the tree. All the possible call-back and
@@ -534,9 +534,9 @@ C<scan_list> are not required. This is done once the hook returns.
 C<check_list_element_cb>: Like C<list_element_cb>, but called on a
 check_list element.
 
- ($scanner, $data_ref,$node,$element_name,@check_items)
+ ($scanner, $data_ref,$node,$element_name, index, check_list_obj)
 
-C<@check_items> is a list containing all the items of the check_list.
+C<index> is always undef as a check_list cannot be contained in a hash or list (yet)
 
 =head2 Hash element callback
 
@@ -649,7 +649,9 @@ Example:
 
 =head1 METHODS
 
-=head2 scan_node ($data_r,$node)
+=head2 scan_node
+
+Parameters: C<< ($data_r,$node) >>
 
 Explore the node and call either C<node_dispatch_cb> (if the node class
 name matches the dispatch_node hash) B<or> (e.g. xor) C<node_element_cb> passing
@@ -657,24 +659,32 @@ all element names.
 
 C<up_cb> is called once the first callback returns.
 
-=head2 scan_element($data_r,$node,$element_name)
+=head2 scan_element
+
+Parameters: C<< ($data_r,$node,$element_name) >>
 
 Explore the element and call either C<hash_element_cb>,
 C<list_element_cb>, C<node_content_cb> or a leaf call-back (the leaf
 call-back called depends on the Value object properties: enum, string,
 integer and so on)
 
-=head2 scan_hash ($data_r,$node,$element_name,$key)
+=head2 scan_hash
+
+Parameters: C<< ($data_r,$node,$element_name,$key) >>
 
 Explore the hash member (or hash value) and call either C<node_content_cb> or
 a leaf call-back.
 
-=head2 scan_list ($data_r,$node,$element_name,$index)
+=head2 scan_list
+
+Parameters: C<< ($data_r,$node,$element_name,$index) >>
 
 Just like C<scan_hash>: Explore the list member and call either
 C<node_content_cb> or a leaf call-back.
 
-=head2 get_keys ($node, $element_name)
+=head2 get_keys
+
+Parameters: C<< ($node, $element_name) >>
 
 Returns an list containing the sorted keys of a hash element or returns
 an list containing (0.. last_index) of an list element.
