@@ -8,10 +8,11 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::TreeSearcher;
-$Config::Model::TreeSearcher::VERSION = '2.117';
+$Config::Model::TreeSearcher::VERSION = '2.133';
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
+use List::MoreUtils qw/any/;
 use Log::Log4perl qw(get_logger :levels);
 use Config::Model::Exception;
 use Config::Model::ObjTreeScanner;
@@ -75,7 +76,7 @@ sub search {
         if ( $need_search->{help} ) {
             my $help_ref = $leaf_object->get_help;
             $data_ref->($loc)
-                if grep { $_ =~ $reg; } values %$help_ref;
+                if any { $_ =~ $reg; } values %$help_ref;
         }
     };
 
@@ -147,7 +148,7 @@ Config::Model::TreeSearcher - Search tree for match in value, description...
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -221,11 +222,13 @@ Search in all the items above
 
 =head1 Methods
 
-=head2 search(keyword)
+=head2 search
+
+Parameters: C<< (keyword) >>
 
 Search the keyword or pattern in the tree. The search is done in a case
-insensitive manner. Returns a list of path pointing 
-to the matching tree element. See L<Config::Model::Role::Grab/grab> for details
+insensitive manner. Returns a list of path pointing
+to the matching tree elements. See L<Config::Model::Role::Grab/grab> for details
 on the path syntax.
 
 =head1 BUGS
