@@ -8,9 +8,12 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Value;
-$Config::Model::Value::VERSION = '2.117';
+$Config::Model::Value::VERSION = '2.133';
 use 5.10.1;
 
+use strict;
+use warnings;
+
 use Mouse;
 use Mouse::Util::TypeConstraints;
 use MouseX::StrictConstructor;
@@ -37,6 +40,7 @@ with "Config::Model::Role::HelpAsText";
 with "Config::Model::Role::ComputeFunction";
 
 my $logger        = get_logger("Tree::Element::Value");
+my $user_logger   = get_logger("User");
 my $change_logger = get_logger("Anything::Change");
 my $fix_logger    = get_logger("Anything::Fix");
 
@@ -179,9 +183,12 @@ sub notify_change {
 
     return if $self->instance->initial_load and not $args{really};
 
-    $change_logger->trace( "called while needs_check is ",
-        $self->needs_check, " for ", $self->name, " with ", join( ' ', %args ) )
-        if $change_logger->is_trace;
+    if ($change_logger->is_trace) {
+        my @a = map { ( $_ => $args{$_} // '<undef>' ); } sort keys %args;
+        $change_logger->trace( "called while needs_check is ",
+        $self->needs_check, " for ", $self->name, " with ", join( ' ', @a ) );
+    }
+
     $self->needs_check(1) unless $check_done;
     {
         no warnings 'uninitialized';
@@ -347,6 +354,13 @@ sub set_migrate_from {
 sub migrate_value {
     my $self = shift;
 
+    # migrate value is always used as a scalar, even in list
+    # context. Not returning undef would break a hash assignment done
+    # with something like:
+    # my %args =  (value => $obj->migrate_value, fix => 1).
+
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
+
     return undef if $self->{migration_done};
     return undef if $self->instance->initial_load;
     $self->{migration_done} = 1;
@@ -518,7 +532,6 @@ sub set_properties {
     # these are handled by Node or Warper
     map { delete $args{$_} } qw/level/;
 
-    my $logger = $logger;
     if ( $logger->is_trace ) {
         $logger->trace( "Leaf '" . $self->name . "' set_properties called with '",
             join( "','", sort keys %args ), "'" );
@@ -716,9 +729,14 @@ sub get_help {
     return $help unless @_;
 
     my $on_value = shift;
-    return $help->{$on_value} if defined $help and defined $on_value;
+    return unless defined $on_value;
 
-    return;
+    my $fallback = $help->{'.'} || $help -> {'.*'};
+    foreach my $k (sort { length($b) cmp length($a) } keys %$help) {
+        next if $k eq '' or $k eq '.*';
+        return $help->{$k} if $on_value =~ /^$k/;
+    }
+    return $fallback;
 }
 
 # construct an error message for enum types
@@ -877,25 +895,30 @@ sub check_value {
 
     if ( $mode ne 'custom' ) {
         if ( $self->{warn_if_match} ) {
-            my $test_sub = sub { my ( $v, $r ) = @_; $v =~ /$r/ ? 0 : 1; };
+            my $test_sub = sub {
+                my $v = shift // '';
+                my $r = shift;
+                $v =~ /$r/ ? 0 : 1;
+            };
             $self->run_regexp_set_on_value( \$value, $apply_fix, \@warn, 'not ', $test_sub,
                 $self->{warn_if_match} );
         }
 
         if ( $self->{warn_unless_match} ) {
-            my $test_sub = sub { my ( $v, $r ) = @_; $v =~ /$r/ ? 1 : 0; };
+            my $test_sub = sub {
+                my $v = shift // '';
+                my $r = shift;
+                $v =~ /$r/ ? 1 : 0;
+            };
             $self->run_regexp_set_on_value( \$value, $apply_fix, \@warn, '', $test_sub,
                 $self->{warn_unless_match} );
         }
 
-        $self->run_code_set_on_value( \$value, $apply_fix, \@error, "assert failure",
-            $self->{assert} )
+        $self->run_code_set_on_value( \$value, $apply_fix, \@error, $self->{assert} )
             if $self->{assert};
-        $self->run_code_set_on_value( \$value, $apply_fix, \@warn,
-            "warn_unless code check returned false", $self->{warn_unless} )
+        $self->run_code_set_on_value( \$value, $apply_fix, \@warn, $self->{warn_unless} )
             if $self->{warn_unless};
-        $self->run_code_set_on_value( \$value, $apply_fix, \@warn,
-            "warn_if code check returned true", $self->{warn_if}, 1 )
+        $self->run_code_set_on_value( \$value, $apply_fix, \@warn, $self->{warn_if}, 1 )
             if $self->{warn_if};
     }
 
@@ -976,24 +999,24 @@ sub run_code_on_value {
 }
 
 sub run_code_set_on_value {
-    my ( $self, $value_r, $apply_fix, $array, $msg, $w_info, $invert ) = @_;
+    my ( $self, $value_r, $apply_fix, $array, $w_info, $invert ) = @_;
 
     $self->set_val;
 
     foreach my $label ( sort keys %$w_info ) {
         my $code = $w_info->{$label}{code};
-        my $msg = $w_info->{$label}{msg} || $msg;
+        my $msg = $w_info->{$label}{msg} || $label;
         $logger->trace("eval'ed code is: '$code'");
         my $fix = $w_info->{$label}{fix};
 
         my $sub = sub {
             local $_ = shift;
             no warnings "uninitialized";
-            my $ret = eval($code);
+            my $ret = eval($code); ## no critic (ProhibitStringyEval)
             if ($@) {
                 Config::Model::Exception::Model->throw(
                     object  => $self,
-                    message => "Eval of code failed : $@"
+                    message => "Eval of assert or warning code failed : $@"
                 );
             }
             return $invert ^ $ret;
@@ -1004,7 +1027,7 @@ sub run_code_set_on_value {
 }
 
 sub run_regexp_set_on_value {
-    my ( $self, $value_r, $apply_fix, $array, $msg, $test_sub, $w_info ) = @_;
+    my ( $self, $value_r, $apply_fix, $array, $may_be, $test_sub, $w_info ) = @_;
 
     # no need to check default or computed values
     return unless defined $$value_r;
@@ -1012,7 +1035,7 @@ sub run_regexp_set_on_value {
     foreach my $rxp ( sort keys %$w_info ) {
         # $_[0] is set to $$value_r when $sub is called
         my $sub = sub { $test_sub->( $_[0], $rxp ) };
-        my $msg = $w_info->{$rxp}{msg} || "value '$$value_r' should $msg" . "match regexp $rxp";
+        my $msg = $w_info->{$rxp}{msg} || "value should ${may_be}match regexp '$rxp'";
         my $fix = $w_info->{$rxp}{fix};
         $self->run_code_on_value( $value_r, $apply_fix, $array, 'regexp', $sub, $msg, $fix );
     }
@@ -1062,7 +1085,7 @@ sub apply_fix {
 
     $self->set_val;
 
-    eval($fix);
+    eval($fix); ## no critic (ProhibitStringyEval)
     if ($@) {
         Config::Model::Exception::Model->throw(
             object  => $self,
@@ -1073,7 +1096,9 @@ sub apply_fix {
     no warnings "uninitialized";
     if ( $_ ne $$value_r ) {
         $fix_logger->info( $self->location . ": fix changed value from '$$value_r' to '$_'" );
+        $DB::single =1 if $self-> element_name =~ /undef/;
         $self->_store_fix( $$value_r, $_, $msg );
+        $$value_r = $_; # so chain of fixes work
     }
     else {
         $fix_logger->info( $self->location . ": fix did not change value '$$value_r'" );
@@ -1087,11 +1112,18 @@ sub _store_fix {
 
     if ( $fix_logger->is_trace ) {
         $fix_logger->trace(
-            "fix change: '" . ( $old // '<undef>' ) . "' -> '" . ( $new // '<undef>' ) . "'" );
+            "fix change: '" . ( $old // '<undef>' ) . "' -> '" . ( $new // '<undef>' ) . "'"
+        );
     }
 
     my $new_v = $new // $self->_fetch_std ;
-    my $old_v => $old // $self->_fetch_std;
+    my $old_v = $old // $self->_fetch_std;
+
+    if ( $fix_logger->is_trace ) {
+        $fix_logger->trace(
+            "fix change (with std value)): '" . ( $old // '<undef>' ) . "' -> '" . ( $new // '<undef>' ) . "'"
+        );
+    }
 
     no warnings "uninitialized";
     # in case $old is the default value and $new is undef
@@ -1142,9 +1174,17 @@ sub check_fetched_value {
         $logger->debug("is not needed");
     }
 
+    $self->store_warning($value, $silent);
+
+    return wantarray ? $self->all_errors : $self->is_ok;
+}
+
+sub store_warning {
+    my ($self, $value, $silent) = @_ ;
+
     # old_warn is used to avoid warning the user several times for the
-    # same reason. We take care to clean up this hash each time this routine
-    # is run
+    # same reason (i.e. when storing and fetching value). We take care
+    # to clean up this hash each time store is run
     my $old_warn = $self->{old_warning_hash} || {};
     my %warn_h;
 
@@ -1152,13 +1192,18 @@ sub check_fetched_value {
         foreach my $w ( $self->all_warnings ) {
             $warn_h{$w} = 1;
             next if $old_warn->{$w};
-            my $str = defined $value ? "'$value'" : '<undef>';
-            warn "Warning in '" . $self->location_short . "' value $str: $w\n";
+            my $str = $value // '<undef>';
+            chomp $str;
+            my $w_str = $str =~ /\n/ ? "\n+++++\n$str\n+++++" : "'$str'";
+            if ($::_use_log4perl_to_warn) {
+                $user_logger->warn("Warning in '" . $self->location_short . "': $w\nOffending value: $w_str");
+            }
+            else {
+                warn "Warning in '" . $self->location_short . "': $w\nOffending value: $w_str\n";
+            }
         }
     }
     $self->{old_warning_hash} = \%warn_h;
-
-    return wantarray ? $self->all_errors : $self->is_ok;
 }
 
 sub store {
@@ -1264,7 +1309,7 @@ sub _store {
 
     if ( $logger->is_debug ) {
         my $i   = $self->instance;
-        my $msg = "value store $value, ok '$ok', check is $check";
+        my $msg = "value store ". ($value // '<undef>')." ok '$ok', check is $check";
         map { $msg .= " $_" if $i->$_() } qw/layered preset/;
         $logger->debug($msg);
     }
@@ -1285,7 +1330,12 @@ sub _store {
             if (not $silent and $msg) {
                 # fuse UI exits when a warning is issued. No other need to advertise this option
                 print $msg if $args{say_dont_warn};
-                warn $msg unless $args{say_dont_warn};
+                if ($::_use_log4perl_to_warn) {
+                    $user_logger->warn($msg) unless $args{say_dont_warn};
+                }
+                else {
+                    warn $msg unless $args{say_dont_warn};
+                }
             }
         }
         else {
@@ -1407,17 +1457,10 @@ sub check_stored_value {
 
     $self->needs_check(0) unless $self->has_error or $self->has_warning;
 
-    # avoid warning the user several times for the same value (at
-    # store time and then at fetch time).
-    my %warn_h;
-    if ( $self->has_warning and not $nowarning and not $silent ) {
-        foreach my $w ( $self->all_warnings ) {
-            $warn_h{$w} = 1;
-            my $str = defined $value ? "'$value'" : '<undef>';
-            warn "Warning in '" . $self->location_short . "' value $str: $w\n";
-        }
-    }
-    $self->{old_warning_hash} = \%warn_h;
+    # must always warn when storing a value, hence clearing the list
+    # of already issued warnings
+    $self->{old_warning_hash} = {};
+    $self->store_warning($value, $silent);
 
     return wantarray ? ($ok,$fixed_value) : $ok;
 }
@@ -1443,7 +1486,9 @@ sub load_data {
     my %args  = @_ > 1 ? @_ : ( data => shift );
     my $data  = delete $args{data} // delete $args{value};
 
-    if ( ref $data ) {
+    my $rd = ref $data;
+
+    if ( $rd and grep { $rd eq $_ } qw/ARRAY HASH SCALAR/) {
         Config::Model::Exception::LoadData->throw(
             object     => $self,
             message    => "load_data called with non scalar arg",
@@ -1452,7 +1497,8 @@ sub load_data {
     }
     else {
         if ( $logger->is_info ) {
-            $logger->info( "Value load_data (", $self->location, ") will store value $data" );
+            my $str = $data // '<undef>';
+            $logger->info( "Value load_data (", $self->location, ") will store value $str" );
         }
         $self->store(%args, value => $data);
     }
@@ -1719,9 +1765,17 @@ sub fetch {
     elsif ( $check eq 'skip' ) {
         my $msg = $self->error_msg;
         my $str = $value // '<undef>';
-        warn "Warning: fetch [".$self->name,"] skipping value $str because of the following errors:\n$msg\n\n"
+        if ($::_use_log4perl_to_warn) {
+            $user_logger->warn("Warning: fetch [".$self->name,"] skipping value $str because of the following errors:\n$msg\n")
             if not $silent and $msg;
-        return undef;
+        }
+        else {
+            warn "Warning: fetch [".$self->name,"] skipping value $str because of the following errors:\n$msg\n\n"
+                if not $silent and $msg;
+        }
+        # this method is supposed to return a scalar
+        return undef; ## no critic(Subroutines::ProhibitExplicitReturnUndef)
+
     }
 
     Config::Model::Exception::WrongValue->throw(
@@ -1734,20 +1788,28 @@ sub fetch {
 
 sub map_write_as {
     my $self = shift;
-    my @res = map {
-        my $do_map = (defined $_ and $self->{write_as} and $self->value_type eq 'boolean');
-        $do_map ? $self->{write_as}[$_] : $_;
-    } @_ ;
+    my @res;
+    if ($self->{write_as} and $self->value_type eq 'boolean') {
+        foreach my $v (@_) {
+            push @res, ( defined $v and $v =~ /^\d+$/ ) ? $self->{write_as}[$v] : $v;
+        }
+    }
+    else {
+        @res = @_;
+    }
     return wantarray ? @res : $res[0];
 }
 
-# modifies in place the passed values (which are also returned)
+# modifies in place the passed values
 sub map_write_as_inplace {
     my $self = shift;
-    map {
-        $_ = $self->{write_as}[$_]
-            if defined $_ and $self->{write_as} and $self->value_type eq 'boolean';
-    } @_;
+    return unless $self->{write_as} and $self->value_type eq 'boolean';
+
+    foreach (@_) {
+        if (defined $_ and /^\d+$/) {
+            $_ = $self->{write_as}[$_];
+        }
+    }
 }
 
 sub user_value {
@@ -1853,7 +1915,7 @@ Config::Model::Value - Strongly typed configuration value
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -2113,7 +2175,7 @@ perform the test. A warning is issued if the given code returns true.
 C<$_> contains the value to check. C<$self> contains the
 C<Config::Model::Value> object (use with care).
 
-The example below warns if value contaims a number:
+The example below warns if value contains a number:
 
  warn_if => {
     warn_test => {
@@ -2123,6 +2185,14 @@ The example below warns if value contaims a number:
     }
  },
 
+Hash key is used in warning message when C<msg> is not set:
+
+ warn_if => {
+   'should begin with foo' => {
+        code => 'defined && /^foo/'
+   }
+ }
+
 Any operation or check on file must be done with C<file> sub
 (otherwise tests will break). This sub returns a L<Path::Tiny>
 object that can be used to perform checks. For instance:
@@ -2140,9 +2210,8 @@ Like C<warn_if>, but issue a warning when the given C<code> returns false.
 The example below warns unless the value points to an existing directory:
 
  warn_unless => {
-     'dir' => {
+     'missing dir' => {
           code => '-d',
-          msg => 'missing dir',
           fix => "system(mkdir $_);" }
  }
 
@@ -2159,6 +2228,8 @@ given code returns false:
     }
  },
 
+hash key can also be used to generate error message when C<msg> parameter is not set.
+
 =item grammar
 
 Setup a L<Parse::RecDescent> grammar to perform validation.
@@ -2228,6 +2299,19 @@ ref. Example:
 
 help => { oui => "French for 'yes'", non => "French for 'no'"}
 
+The key of help is used as a regular expression to find the help text
+applicable to a value. These regexp are tried from the longest to the
+shortest and are matched from the beginning of the string. The key "C<.>"
+or "C<.*>" are fallback used last.
+
+For instance:
+
+ help => {
+   'foobar' => 'help for values matching /^foobar/',
+   'foo' => 'help for values matching /^foo/ but not /^foobar/ (used above)',
+   '.' => 'help for all other values'
+ }
+
 =back
 
 =head2 Value types
@@ -2429,7 +2513,7 @@ the value object (as declared in the model unless they were warped):
 
 =back
 
-=head2 name()
+=head2 name
 
 Returns the object name.
 
@@ -2437,22 +2521,20 @@ Returns the object name.
 
 Returns C<leaf>.
 
-=head2 can_store()
+=head2 can_store
 
 Returns true if the value object can be assigned to. Return 0 for a
 read-only value (i.e. a computed value with no override allowed).
 
-=head2 get_choice()
+=head2 get_choice
 
 Query legal values (only for enum types). Return an array (possibly
 empty).
 
-=head2 get_help ( [ on_value ] )
+=head2 get_help
 
-Returns the help strings passed to the constructor.
-
-With C<on_value> parameter, returns the help string dedicated to the
-passed value or undef.
+With a parameter, returns the help string applicable to the passed
+value or undef.
 
 Without parameter returns a hash ref that contains all the help strings.
 
@@ -2465,7 +2547,9 @@ Returns the error messages of this object (if any)
 Returns warning concerning this value. Returns a list in list
 context and a string in scalar context.
 
-=head2 check_value ( value )
+=head2 check_value
+
+Parameters: C<< ( value ) >>
 
 Check the consistency of the value.
 
@@ -2497,7 +2581,9 @@ Returns the number of fixes that can be applied to the current value.
 
 Applies the fixes to suppress the current warnings.
 
-=head2 check( [ value => foo ] )
+=head2 check
+
+Parameters: C<< ( [ value => foo ] ) >>
 
 Like L</check_value>.
 
@@ -2509,9 +2595,10 @@ Without C<value> argument, this method checks the value currently stored.
 
 =head1 Information management
 
-=head2 store( $value )
+=head2 store
 
-Can be called as C<< value => ...,	check => yes|no|skip ), silent => 0|1 >>
+Parameters: C<< ( $value ) >>
+or C<< value => ...,	check => yes|no|skip ), silent => 0|1 >>
 
 Store value in leaf element. C<check> parameter can be used to
 skip validation check (default ies 'yes').
@@ -2524,11 +2611,13 @@ Optional C<callback> is now deprecated.
 Clear the stored value. Further read returns the default value (or
 computed or migrated value).
 
-=head2 load_data( $value )
+=head2 load_data
 
-Load scalar data. Data is forwarded to L</"store( $value )">.
+Parameters: C<< ( $value ) >>
 
-Called with C<load_data( $value )> or C<load_data( data => $value )> or
+Load scalar data. Data is forwarded to L</"store">.
+
+Called with C<load_data> or C<load_data> or
 with the same parameters are C<store> method.
 
 =head2 fetch_custom
@@ -2549,7 +2638,7 @@ default value or a built-in default value.
 Return true if the value contains information different from default
 or upstream default value.
 
-=head2 fetch(...)
+=head2 fetch
 
 Check and fetch value from leaf element. The method can have one parameter (the fetch mode)
 or several pairs:
