@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Value::LayeredInclude;
-$Config::Model::Value::LayeredInclude::VERSION = '2.117';
+$Config::Model::Value::LayeredInclude::VERSION = '2.133';
 use 5.010;
 use strict;
 use warnings;
@@ -81,13 +81,12 @@ sub _check_value {
 
     # need to test that prest config file is present as the model
     # may not enforce it (when read_config auto_create is 1)
-    my $layered_file = $self->instance->root_dir;
-    $layered_file .= $value;
+    my $layered_file = $self->instance->root_dir->child($value);
 
     my $err = $self->{error_list};
 
-    if ( not -r $layered_file ) {
-        push @$err, "cannot read include file $$layered_file";
+    if ( not $layered_file->is_file ) {
+        push @$err, "cannot read include file $layered_file";
     }
 
     return wantarray ? @$err : scalar @$err ? 0 : 1;
@@ -108,7 +107,7 @@ Config::Model::Value::LayeredInclude - Include a sub layer configuration
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
