@@ -8,13 +8,14 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Warper;
-$Config::Model::Warper::VERSION = '2.117';
+$Config::Model::Warper::VERSION = '2.133';
 use Mouse;
 
 use Log::Log4perl qw(get_logger :levels);
 use Data::Dumper;
 use Storable qw/dclone/;
 use Config::Model::Exception;
+use List::MoreUtils qw/any/;
 use Carp;
 
 has 'follow' => ( is => 'ro', isa => 'HashRef[Str]', required => 1 );
@@ -48,10 +49,12 @@ sub _get_value_gist {
     return ref($item) eq 'HASH' ? join(',', each %$item) : $item;
 }
 
-has _computed_masters => ( is => 'rw', isa => 'HashRef', init_arg => undef );
-
-has [qw/_warped_nodes _registered_values/] =>
-    ( is => 'rw', isa => 'HashRef', init_arg => undef, default => sub { {} }, );
+has [qw/ _computed_masters _warped_nodes _registered_values/] => (
+    is => 'rw',
+    isa => 'HashRef',
+    init_arg => undef, # can't use this param in constructor
+    default => sub { {} },
+);
 
 has allowed => ( is => 'rw', isa => 'ArrayRef' );
 has morph   => ( is => 'ro', isa => 'Bool' );
@@ -319,7 +322,7 @@ sub check_warp_args {
                     . "parameter is not allowed, "
                     . "expected '"
                     . join( "' or '", @$allowed ) . "'"
-            ) unless grep( $pkey eq $_, @$allowed );
+            ) unless any {$pkey eq $_}  @$allowed ;
         }
     }
 }
@@ -620,7 +623,7 @@ Config::Model::Warper - Warp tree properties
 
 =head1 VERSION
 
-version 2.117
+version 2.133
 
 =head1 SYNOPSIS
 
@@ -788,7 +791,7 @@ be shown or not (assuming C<FooClass> and C<BarClass> classes are declared):
 
 =head1 Methods
 
-=head2 warp_error()
+=head2 warp_error
 
 This method returns a string describing:
 
