@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2016 by Dominique Dumont.
+# This software is Copyright (c) 2005-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -32,13 +32,11 @@
     ],
     'license' => 'LGPL2',
     'name' => 'Fstab',
-    'read_config' => [
-      {
-        'backend' => 'Fstab',
-        'config_dir' => '/etc',
-        'file' => 'fstab'
-      }
-    ]
+    'rw_config' => {
+      'backend' => 'Fstab',
+      'config_dir' => '/etc',
+      'file' => 'fstab'
+    }
   }
 ]
 ;
